Environment
=========================
This module implements environments and sample functions that could be used to generate trajectories.

.. code-block:: python
    
    from pycfrl import environment

.. automodule:: pycfrl.environment
   :members:
   :show-inheritance:
   :special-members: __init__